==> lyform-0.3.1.tar.gz: README.md <==
# LyForm

[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg?label=license)](https://opensource.org/licenses/MIT)
[![Version](https://img.shields.io/pub/v/lyform)](https://pub.dev/packages/lyform)
[![codecov](https://codecov.io/gh/lynotofficial/lynot-dart-flutter/branch/main/graph/badge.svg?token=RTBS8EX4GQ)](https://codecov.io/gh/lynotofficial/lynot-dart-flutter)
[![Test](https://github.com/lynotofficial/lynot-dart-flutter/actions/workflows/test.yml/badge.svg)](https://github.com/lynotofficial/lynot-dart-flutter/actions/workflows/test.yml)
[![Melos](https://img.shields.io/badge/maintained%20with-melos-f700ff.svg?style=flat-square)](https://github.com/invertase/melos) [![Lint](https://img.shields.io/badge/style-lint-4BC0F.svg)](https://pub.dev/packages/lint)
[![Last commit](https://img.shields.io/github/last-commit/lynotofficial/lynot-dart-flutter.svg?style=flat)](https://github.com/lynotofficial/lynot-dart-flutter/commits)
[![GitHub commit activity](https://img.shields.io/github/commit-activity/m/lynotofficial/lynot-dart-flutter)](https://github.com/lynotofficial/lynot-dart-flutter/commits)
[![Github Stars](https://img.shields.io/github/stars/lynotofficial/lynot-dart-flutter?style=flat&logo=github)](https://github.com/lynotofficial/lynot-dart-flutter/stargazers)
[![Github Forks](https://img.shields.io/github/forks/lynotofficial/lynot-dart-flutter?style=flat&logo=github)](https://github.com/lynotofficial/lynot-dart-flutter/network/members)
[![Github Watchers](https://img.shields.io/github/watchers/lynotofficial/lynot-dart-flutter?style=flat&logo=github)](https://github.com/lynotofficial/lynot-dart-flutter)
[![GitHub contributors](https://img.shields.io/github/contributors/lynotofficial/lynot-dart-flutter?label=code%20contributors)](https://github.com/lynotofficial/lynot-dart-flutter/graphs/contributors)

---

Dart package to implement forms in an easy, fast and effective way using the [bloc](https://pub.dev/packages/bloc) package.

## Sponsored with 💖 by

[![MeSirve](https://mesirve.app/icons/Icon-192.png)](https://mesirve.app)

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/70nybl4nc0"><img src="https://avatars.githubusercontent.com/u/34517439?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Tony Raul Blanco Fernandez</b></sub></a><br /><a href="https://github.com/lynotofficial/lynot-dart-flutter/commits?author=70nybl4nc0" title="Code">💻</a> <a href="#maintenance-70nybl4nc0" title="Maintenance">🚧</a></td>
    <td align="center"><a href="http://leynier.github.io"><img src="https://avatars.githubusercontent.com/u/36774373?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Leynier Gutiérrez González</b></sub></a><br /><a href="https://github.com/lynotofficial/lynot-dart-flutter/commits?author=leynier" title="Code">💻</a> <a href="https://github.com/lynotofficial/lynot-dart-flutter/commits?author=leynier" title="Documentation">📖</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

==> lyform-0.6.1.tar.gz: README.md <==
# LyForm

[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg?label=license)](https://opensource.org/licenses/MIT)
[![Version](https://img.shields.io/pub/v/lyform)](https://pub.dev/packages/lyform)
[![codecov](https://codecov.io/gh/lynotofficial/lynot-dart-flutter/branch/main/graph/badge.svg?token=RTBS8EX4GQ)](https://codecov.io/gh/lynotofficial/lynot-dart-flutter)
[![Test](https://github.com/lynotofficial/lynot-dart-flutter/actions/workflows/test.yml/badge.svg)](https://github.com/lynotofficial/lynot-dart-flutter/actions/workflows/test.yml)
[![Melos](https://img.shields.io/badge/maintained%20with-melos-f700ff.svg?style=flat-square)](https://github.com/invertase/melos) [![Lint](https://img.shields.io/badge/style-lint-4BC0F.svg)](https://pub.dev/packages/lint)
[![Last commit](https://img.shields.io/github/last-commit/lynotofficial/lynot-dart-flutter.svg?style=flat)](https://github.com/lynotofficial/lynot-dart-flutter/commits)
[![GitHub commit activity](https://img.shields.io/github/commit-activity/m/lynotofficial/lynot-dart-flutter)](https://github.com/lynotofficial/lynot-dart-flutter/commits)
[![Github Stars](https://img.shields.io/github/stars/lynotofficial/lynot-dart-flutter?style=flat&logo=github)](https://github.com/lynotofficial/lynot-dart-flutter/stargazers)
[![Github Forks](https://img.shields.io/github/forks/lynotofficial/lynot-dart-flutter?style=flat&logo=github)](https://github.com/lynotofficial/lynot-dart-flutter/network/members)
[![Github Watchers](https://img.shields.io/github/watchers/lynotofficial/lynot-dart-flutter?style=flat&logo=github)](https://github.com/lynotofficial/lynot-dart-flutter)
[![GitHub contributors](https://img.shields.io/github/contributors/lynotofficial/lynot-dart-flutter?label=code%20contributors)](https://github.com/lynotofficial/lynot-dart-flutter/graphs/contributors)

---

Dart package to implement forms in an easy, fast and effective way using the [bloc](https://pub.dev/packages/bloc) package.

## Sponsored with 💖 by

[![MeSirve](https://mesirve.app/icons/Icon-192.png)](https://mesirve.app)

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/70nybl4nc0"><img src="https://avatars.githubusercontent.com/u/34517439?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Tony Raul Blanco Fernandez</b></sub></a><br /><a href="https://github.com/lynotofficial/lynot-dart-flutter/commits?author=70nybl4nc0" title="Code">💻</a> <a href="#maintenance-70nybl4nc0" title="Maintenance">🚧</a></td>
    <td align="center"><a href="https://leynier.github.io"><img src="https://avatars.githubusercontent.com/u/36774373?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Leynier Gutiérrez González</b></sub></a><br /><a href="https://github.com/lynotofficial/lynot-dart-flutter/commits?author=leynier" title="Code">💻</a> <a href="https://github.com/lynotofficial/lynot-dart-flutter/commits?author=leynier" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/lagcleaner"><img src="https://avatars.githubusercontent.com/u/45600122?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Leonel</b></sub></a><br /><a href="https://github.com/lynotofficial/lynot-dart-flutter/commits?author=lagcleaner" title="Code">💻</a> <a href="https://github.com/lynotofficial/lynot-dart-flutter/issues?q=author%3Alagcleaner" title="Bug reports">🐛</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!
